import { Component, Input, Output, EventEmitter } from '@angular/core';
var AlertcardComponent = /** @class */ (function () {
    function AlertcardComponent() {
        this.save = new EventEmitter();
        this.dropdownSettings = {};
    }
    // User clicked a delivery option checkbox
    AlertcardComponent.prototype.deliveryOptionChanged = function (id) {
        var foundAt = this.deliverTo.indexOf(id);
        if (foundAt >= 0) {
            // Remove
            this.deliverTo.splice(foundAt, 1);
        }
        else {
            // Add
            this.deliverTo.push(id);
        }
        this.isDirty = true;
    };
    AlertcardComponent.prototype.ngOnInit = function () {
        this.init();
        this.dropdownSettings = {
            singleSelection: false,
            text: 'Select',
            selectAllText: 'Select All',
            unSelectAllText: 'UnSelect All',
            enableSearchFilter: true,
            classes: 'np-dropdown'
        };
    };
    AlertcardComponent.prototype.onItemSelect = function (item) {
        this.isDirty = true;
    };
    AlertcardComponent.prototype.OnItemDeSelect = function (item) {
        this.isDirty = true;
    };
    AlertcardComponent.prototype.onSelectAll = function (items) {
        this.isDirty = true;
    };
    AlertcardComponent.prototype.onDeSelectAll = function (items) {
        this.isDirty = true;
    };
    AlertcardComponent.prototype.ngOnChanges = function () {
        this.init();
    };
    AlertcardComponent.prototype.init = function () {
        this.isDirty = false;
        // Save the original values passed into this component
        this.active = this.alertPref.active;
        // Convert deliverTo values into a list of ids
        this.deliverTo = new Array();
        var _loop_1 = function (deliverToValue) {
            var deliveryOption = this_1.deliveryOptions.find(function (item) { return item.value === deliverToValue; });
            if (deliveryOption) {
                this_1.deliverTo.push(deliveryOption.id);
            }
        };
        var this_1 = this;
        for (var _i = 0, _a = this.alertPref.deliverTo; _i < _a.length; _i++) {
            var deliverToValue = _a[_i];
            _loop_1(deliverToValue);
        }
        // Create a deep copy of the parameters (in case the user clicks cancel)
        this.parameters = JSON.parse(JSON.stringify(this.alertPref.parameters));
        // Copy any external parameters passed in from the component
        for (var _b = 0, _c = this.alertPref.alertDef.parameters; _b < _c.length; _b++) {
            var parameter = _c[_b];
            var externalValue = this.externalParameters ? this.externalParameters[parameter.name] : null;
            if (externalValue) {
                this.parameters[parameter.name] = externalValue;
            }
        }
    };
    // Finds the lookup list of the given name
    AlertcardComponent.prototype.findLookup = function (name) {
        return this.alertPref.alertDef.lookupLists.find(function (i) { return i.name === name; }).values;
    };
    AlertcardComponent.prototype.statusChanged = function () {
        this.isDirty = true;
        // If turning off, then go ahead and save
        if (!this.active) {
            this.savePref();
        }
    };
    AlertcardComponent.prototype.parameterChanged = function () {
        this.isDirty = true;
    };
    // Save the user inputs back to the passed in preference object
    AlertcardComponent.prototype.savePref = function () {
        this.alertPref.active = this.active;
        // Convert deliverTo ids back to values
        this.alertPref.deliverTo = new Array();
        var _loop_2 = function (i) {
            this_2.alertPref.deliverTo.push(this_2.deliveryOptions.find(function (item) { return item.id === i; }).value);
        };
        var this_2 = this;
        for (var _i = 0, _a = this.deliverTo; _i < _a.length; _i++) {
            var i = _a[_i];
            _loop_2(i);
        }
        this.alertPref.parameters = this.parameters;
        this.isDirty = false;
        this.save.emit(null);
    };
    // Reinitilaze with original values
    AlertcardComponent.prototype.cancelPref = function () {
        this.ngOnInit();
    };
    AlertcardComponent.decorators = [
        { type: Component, args: [{
                    selector: 'np-alertcard',
                    template: "\n    <div class=\"card fluid\">\n      <div class=\"section\">\n        <div>\n          <div>\n            <div style=\"float:right;\">\n              <np-slider [(state)]=\"active\" (stateChange)=\"statusChanged()\"></np-slider>\n            </div>\n            <div class=\"np-alert-name\">{{alertPref.alertDef.name}}</div>\n            <div class=\"np-alert-description\">{{alertPref.alertDef.description}}</div>\n          </div>\n        </div>\n        <div *ngIf=\"active\">\n          <div class=\"np-alert-parameters\">\n            <div *ngFor=\"let parameter of alertPref.alertDef.parameters\">\n              <div *ngIf=\"parameter.label\">\n                <label>{{parameter.label}}</label><br/>\n                <input class=\"np-input\" *ngIf=\"parameter.ptype != 'lookup'\"  [(ngModel)]=\"parameters[parameter.name]\" (keyup)=\"parameterChanged()\">\n\n                <angular2-multiselect *ngIf=\"parameter.ptype == 'lookup'\"\n                [data]=\"findLookup(parameter.lookup)\" [(ngModel)]=\"parameters[parameter.name]\"\n                [settings]=\"dropdownSettings\"\n                (onSelect)=\"statusChanged()\"\n                (onDeSelect)=\"statusChanged()\"\n                (onSelectAll)=\"statusChanged()\"\n                (onDeSelectAll)=\"statusChanged()\"></angular2-multiselect><br>\n              </div>\n            </div>\n          </div>\n          <div class=\"np-alert-deliver-to\">\n            <label for=\"options\">Deliver To:</label>\n            <div *ngFor=\"let option of deliveryOptions\">\n              <div *ngIf=\"option.id\">\n                <input type=\"checkbox\" name=\"options\" value=\"{{option.id}}\" id=\"option{{alertPref.alertDefId}}{{option.id}}\" tabindex=\"0\" (click)=\"deliveryOptionChanged(option.id)\"\n                  [checked]=\"this.deliverTo.indexOf(option.id) >= 0\">\n                <label for=\"option{{alertPref.alertDefId}}{{option.id}}\">{{option.name || option.value}}</label>\n                <svg *ngIf=\"option.deliveryType =='text'\" class=\"np-icon\"><use xlink:href=\"#chat\" /></svg>\n                <svg *ngIf=\"option.deliveryType =='email'\" class=\"np-icon\"><use xlink:href=\"#email\" /></svg>\n              </div>\n            </div>\n          </div>\n          <div>\n            <span *ngIf=\"isDirty\" class=\"np-alert-save-cancel\">\n              <button  (click)=\"savePref()\">Save</button>\n              <button  (click)=\"cancelPref()\">Cancel</button>\n            </span>\n          </div>\n        </div>\n      </div>\n    </div>\n  ",
                    styles: ["\n    h1,h2,h3,h4,h5,h6{line-height:1.2em;margin:0.75rem 0.5rem;font-weight:500}h1 small,h2 small,h3 small,h4 small,h5 small,h6 small{color:#424242;display:block;margin-top:-0.25rem}.np-icon{width:16px;height:13px}.np-dropdown{width:300px}.np-input{border:1px solid #ccc;border-radius:3px;font-size:20px;color:#333;padding:8px;margin-bottom:10px}.np-alert-name{font-weight:bold;font-size:12pt}.np-alert-description{font-size:12pt}.card{display:-webkit-box;-webkit-box-orient:vertical;-webkit-box-pack:justify;-webkit-box-align:center;display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;-webkit-justify-content:space-between;justify-content:space-between;-webkit-align-self:center;align-self:center;position:relative;width:100%;background:#fafafa;border:0.0625rem solid #acacac;margin:0.5rem}.card>.section{box-sizing:border-box;margin:0;border:0;border-radius:0;border-bottom:0.0625rem solid #c9c9c9;padding:0.5rem;width:100%}.card>.section:last-child{border-bottom:0}@media screen and (min-width: 320px){.card{max-width:320px}}.card.fluid{max-width:100%;width:auto}.np-alert-parameters{float:left;padding:20px}.np-alert-deliver-to{float:left;padding:20px}.np-alert-save-cancel{float:right;padding:10px}\n  "]
                },] },
    ];
    /** @nocollapse */
    AlertcardComponent.ctorParameters = function () { return []; };
    AlertcardComponent.propDecorators = {
        'alertPref': [{ type: Input },],
        'deliveryOptions': [{ type: Input },],
        'externalParameters': [{ type: Input },],
        'save': [{ type: Output },],
    };
    return AlertcardComponent;
}());
export { AlertcardComponent };
//# sourceMappingURL=alertcard.component.js.map