import { Component, Input, Output, EventEmitter } from '@angular/core';
import { DeliveryOption } from '../../services/preference/preference';
var DeliveryoptionsComponent = /** @class */ (function () {
    function DeliveryoptionsComponent() {
        this.save = new EventEmitter();
        this.newDeliveryOption = new DeliveryOption();
        this.adding = false;
    }
    DeliveryoptionsComponent.prototype.ngOnInit = function () {
    };
    DeliveryoptionsComponent.prototype.saveDeliveryOption = function ($event) {
        // Update any preference records that reference this delivery option
        for (var _i = 0, _a = this.customerPreference.alertPreferences; _i < _a.length; _i++) {
            var pref = _a[_i];
            // See if the old value was in our list
            var index = pref.deliverTo.indexOf($event.originalValue);
            if (index > -1) {
                // Remove it
                pref.deliverTo.splice(index, 1);
                // Add record for the new value if it doesn't already exist
                if (pref.deliverTo.indexOf($event.newValue) === -1) {
                    pref.deliverTo.push($event.newValue);
                }
            }
        }
        this.save.emit(null);
    };
    DeliveryoptionsComponent.prototype.addDeliveryOption = function () {
        var count = this.customerPreference.deliveryOptions.length;
        this.newDeliveryOption.id = count === 0 ? 1 : this.customerPreference.deliveryOptions[count - 1].id + 1;
        this.newDeliveryOption.status = 'notVerified';
        this.newDeliveryOption.updateType();
        this.customerPreference.deliveryOptions.push(this.newDeliveryOption);
        this.cancelDeliveryOption();
        this.save.emit(null);
    };
    DeliveryoptionsComponent.prototype.cancelDeliveryOption = function () {
        this.adding = false;
        this.newDeliveryOption = new DeliveryOption();
    };
    DeliveryoptionsComponent.prototype.deleteDeliveryOption = function (deliveryOption) {
        // remove from list of delivery options
        this.customerPreference.deliveryOptions.splice(this.customerPreference.deliveryOptions.indexOf(deliveryOption), 1);
        // Remove from any preference records that reference it
        for (var _i = 0, _a = this.customerPreference.alertPreferences; _i < _a.length; _i++) {
            var pref = _a[_i];
            pref.deliverTo.splice(pref.deliverTo.indexOf(deliveryOption.value), 1);
        }
        this.save.emit(null);
    };
    DeliveryoptionsComponent.decorators = [
        { type: Component, args: [{
                    selector: 'np-deliveryoptions',
                    template: "\n    <h4>Delivery options</h4>\n    <div *ngFor=\"let option of this.customerPreference.deliveryOptions\">\n      <np-deliveryoption [deliveryOption]=\"option\" (save)=\"saveDeliveryOption($event)\" (delete)=\"deleteDeliveryOption(option)\"></np-deliveryoption>\n    </div>\n    <button *ngIf=\"!adding\" class=\"np-button\" (click)=\"adding=true\">New Delivery Option</button>\n    <div *ngIf=\"adding\" class=\"np-add-delivery-option\">\n        <p class=\"np-instruction\">Enter an email address or mobile phone number:</p>\n        <input [(ngModel)]=\"newDeliveryOption.value\" placeholder=\"email or mobile number\" />\n        <input [(ngModel)]=\"newDeliveryOption.name\" placeholder=\"Nickname (optional)\" />\n        <span>\n          <button class=\"np-button\" (click)=\"addDeliveryOption()\" *ngIf=\"newDeliveryOption.value\">Save</button>\n          <button class=\"np-button\" (click)=\"cancelDeliveryOption()\">Cancel</button>\n        </span>\n    </div>\n  ",
                    styles: ["\n    .np-add-delivery-option{background-color:#eee;padding:10px;max-width:fit-content;margin-top:5px}.np-instruction{margin-bottom:2px;margin-top:2px}\n  "]
                },] },
    ];
    /** @nocollapse */
    DeliveryoptionsComponent.ctorParameters = function () { return []; };
    DeliveryoptionsComponent.propDecorators = {
        'customerPreference': [{ type: Input },],
        'save': [{ type: Output },],
    };
    return DeliveryoptionsComponent;
}());
export { DeliveryoptionsComponent };
//# sourceMappingURL=deliveryoptions.component.js.map